import requests
from mailersend.base import base


class NewDomain(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewDomain, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getDomains(self):
        request = requests.get(f"{self.api_base}/domains", headers=self.headers_default)
        return request.text

    def getDomainById(self, domainId):
        self.domainId = domainId

        request = requests.get(
            f"{self.api_base}/domains/{domainId}", headers=self.headers_default
        )
        return request.text

    def deleteDomain(self, domainId):
        self.domainId = domainId

        request = requests.delete(
            f"{self.api_base}/domains/{domainId}", headers=self.headers_default
        )
        return request.status_code

    def getRecipientsForDomain(self, domainId):
        self.domainId = domainId

        request = requests.get(
            f"{self.api_base}/domains/{domainId}/recipients",
            headers=self.headers_default,
        )
        return request.text

    def updateDomainSetting(self, domainId, key, value):
        self.domainId = domainId

        data = {f"{key}": value}

        request = requests.put(
            f"{self.api_base}/domains/{domainId}/settings",
            headers=self.headers_default,
            json=data,
        )
        return request.text



import json
import os
import requests

API_BASE = "https://api.mailersend.com/v1"
API_KEY = os.environ.get("MAILERSEND_API_KEY")


class NewAPIClient(object):
    def __init__(
        self,
        api_base=None,
        headers_default=None,
        headers_auth=None,
        mailersend_api_key=None,
    ):

        self.api_base = API_BASE
        self.mailersend_api_key = API_KEY
        self.headers_auth = f"Bearer {self.mailersend_api_key}"
        self.headers_default = {
            "Content-Type": "application/json",
            "X-Requested-With": "XMLHttpRequest",
            "User-Agent": "MailerSend-Client-python-v1",
            "Authorization": f"{self.headers_auth}",
        }

    def generateConfigChangeBody(self, key, value):
        self.key = key
        self.value = value

        data = {key: value}

        return data



import requests
from mailersend.base import base

data = {}


class NewWebhook(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewWebhook, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getWebhooks(self, domain_id):
        request = requests.get(
            f"{self.api_base}/webhooks",
            headers=self.headers_default,
            json={"domain_id": domain_id},
        )
        return request.text

    def getWebhookByID(self, webhook_id):
        request = requests.get(
            f"{self.api_base}/webhooks/{webhook_id}", headers=self.headers_default
        )
        return request.text

    def setWebhookURL(self, webhook_url):
        data["url"] = webhook_url

    def setWebhookName(self, webhook_name):
        data["name"] = webhook_name

    def setWebhookEvents(self, events):
        data["events"] = events

    def setWebhookEnabled(self, enabled=True):
        data["enabled"] = enabled

    def setWebhookDomain(self, domain_id):
        data["domain_id"] = domain_id

    def updateWebhook(self, webhook_id, key, value):
        request = requests.put(
            f"{self.api_base}/webhooks/{webhook_id}",
            headers=self.headers_default,
            json={f"{key}": value},
        )
        return request.text

    def deleteWebhook(self, webhook_id):
        request = requests.delete(
            f"{self.api_base}/webhooks/{webhook_id}", headers=self.headers_default
        )
        return request.text

    def createWebhook(self):
        request = requests.post(
            f"{self.api_base}/webhooks", headers=self.headers_default, json=data
        )
        return request.text



import requests
from mailersend.base import base


class NewRecipient(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewRecipient, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getRecipients(self):
        request = requests.get(
            f"{self.api_base}/recipients", headers=self.headers_default
        )
        return request.text

    def getRecipientByID(self, recipientId):
        self.recipientId = recipientId
        request = requests.get(
            f"{self.api_base}/recipients/{recipientId}", headers=self.headers_default
        )
        return request.text

    def deleteRecipient(self, recipientId):
        self.recipientId = recipientId
        request = requests.delete(
            f"{self.api_base}/recipients/{recipientId}", headers=self.headers_default
        )
        return request.status_code



import requests
from mailersend.base import base


class NewAnalytics(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewAnalytics, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getActivityByDate(self, dateFrom, dateTo, event, domainId=None, groupBy=None):
        self.domainId = domainId
        self.dateFrom = dateFrom
        self.dateTo = dateTo
        self.groupBy = groupBy
        self.event = event

        _data = {
            "date_from": dateFrom,
            "date_to": dateTo,
            "event": event,
        }

        if domainId is not None:
            _data["domain_id"] = domainId

        if groupBy is not None:
            _data["group_by"] = groupBy

        request = requests.get(
            f"{self.api_base}/analytics/date", headers=self.headers_default, json=_data
        )

        return request.text

    def getOpensByCountry(self, dateFrom, dateTo, domainId=None, recipients=None):
        self.domainId = domainId
        self.dateFrom = dateFrom
        self.dateTo = dateTo
        self.recipients = recipients

        _data = {
            "date_from": self.dateFrom,
            "date_to": self.dateTo,
        }

        if domainId is not None:
            _data["domain_id"] = domainId

        if recipients is not None:
            _data["recipient_id"] = groupBy

        request = requests.get(
            f"{self.api_base}/analytics/country",
            headers=self.headers_default,
            json=_data,
        )

        return request.text

    def getOpensByUserAgent(self, dateFrom, dateTo, domainId=None, recipients=None):
        self.domainId = domainId
        self.dateFrom = dateFrom
        self.dateTo = dateTo
        self.recipients = recipients

        _data = {
            "date_from": self.dateFrom,
            "date_to": self.dateTo,
        }

        if domainId is not None:
            _data["domain_id"] = domainId

        if recipients is not None:
            _data["recipient_id"] = groupBy

        request = requests.get(
            f"{self.api_base}/analytics/ua-name",
            headers=self.headers_default,
            json=_data,
        )

        return request.text

    def getOpensByReadingEnvironment(
        self, dateFrom, dateTo, domainId=None, recipients=None
    ):
        self.domainId = domainId
        self.dateFrom = dateFrom
        self.dateTo = dateTo
        self.recipients = recipients

        _data = {
            "date_from": self.dateFrom,
            "date_to": self.dateTo,
        }

        if domainId is not None:
            _data["domain_id"] = domainId

        if recipients is not None:
            _data["recipient_id"] = groupBy

        request = requests.get(
            f"{self.api_base}/analytics/ua-type",
            headers=self.headers_default,
            json=_data,
        )

        return request.text



import requests
from mailersend.base import base


class NewHelper(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewHelper, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getIDByName(self, category, name):
        self.category = category
        self.name = name

        request = requests.get(
            f"{self.api_base}/{category}", headers=self.headers_default
        )

        _json_req = request.json()

        category_search_asset = {"recipients": "email", "domains": "name"}

        _data_block = _json_req["data"]

        for data in _data_block:
            if data[category_search_asset.get(category)] == name:
                return data["id"]
            else:
                raise ValueError("Not found")

        return request.text



import requests
from mailersend.base import base


class NewActivity(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewActivity, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getDomainActivity(
        self, domainId, page=None, limit=None, dateFrom=None, dateTo=None, event=None
    ):
        self.domainId = domainId
        self.page = page
        self.limit = limit
        self.dateFrom = dateFrom
        self.dateTo = dateTo
        self.event = event

        _data = {
            "page": page or None,
            "limit": limit or None,
            "dateFrom": dateFrom or None,
            "dateTo": dateTo or None,
            "event": event or None,
        }

        request = requests.get(
            f"{self.api_base}/activity/{domainId}",
            headers=self.headers_default,
            json=_data,
        )
        return request.text



import requests
from mailersend.base import base


class NewMessage(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewMessage, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getMessageById(self, messageId):
        self.messageId = messageId

        request = requests.get(
            f"{self.api_base}/messages/{messageId}", headers=self.headers_default
        )
        return request.text

    def getMessages(self):
        request = requests.get(
            f"{self.api_base}/messages", headers=self.headers_default
        )
        return request.text



import requests
from mailersend.base import base


class NewTemplate(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewTemplate, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def getTemplates(self):
        request = requests.get(
            f"{self.api_base}/templates", headers=self.headers_default
        )
        return request.text

    def getTemplateByID(self, template_id):
        request = requests.get(
            f"{self.api_base}/templates/{template_id}", headers=self.headers_default
        )
        return request.text

    def deleteTemplate(self, template_id):
        request = requests.delete(
            f"{self.api_base}/templates/{template_id}", headers=self.headers_default
        )
        return request.text



import requests
from mailersend.base import base


class NewToken(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewToken, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def createToken(self, tokenName, tokenScopes):
        self.tokenName = tokenName
        self.tokenScopes = tokenScopes

        _data = {"name": tokenName, "scopes": tokenScopes}

        request = requests.post(
            f"{self.api_base}/token", headers=self.headers_default, json=_data
        )
        return request.text

    def updateToken(self, tokenId, pause=True):
        self.tokenId = tokenId
        self.pause = pause

        if pause == True:
            _data = self.generateConfigChangeBody("status", "pause")
        else:
            _data = self.generateConfigChangeBody("status", "unpause")

        request = requests.put(
            f"{self.api_base}/token/{tokenId}/settings",
            headers=self.headers_default,
            json=_data,
        )
        return request.text

    def deleteToken(self, tokenId):
        self.tokenId = tokenId

        request = requests.delete(
            f"{self.api_base}/token/{tokenId}/", headers=self.headers_default
        )
        return request.status_code



import requests
from mailersend.base import base

message = {}


class NewEmail(base.NewAPIClient):
    def __init__(self):
        baseObj = base.NewAPIClient()
        super(NewEmail, self).__init__(
            baseObj.api_base,
            baseObj.headers_default,
            baseObj.headers_auth,
            baseObj.mailersend_api_key,
        )

    def setMailFrom(self, mail_from, message):
        message["from"] = mail_from

    def setMailTo(self, mail_to, message):
        message["to"] = mail_to

    def setSubject(self, subject, message):
        message["subject"] = subject

    def setHTMLContent(self, content, message):
        message["html"] = content

    def setPlaintextContent(self, text, message):
        message["text"] = text

    def setTemplate(self, template_id, message):
        message["template_id"] = template_id

    def setSimplePersonalization(self, personalization, message):
        message["variables"] = personalization

    def setAdvancedPersonalization(self, personalization, message):
        message["personalization"] = personalization

    def setCCRecipients(self, cc, message):
        message["cc"] = cc

    def setBCCRecipients(self, bcc, message):
        message["bcc"] = bcc

    def setTags(self, tags, message):
        message["tags"] = tags

    def setAttachments(self, attachments, message):
        message["attachments"] = attachments

    def send(self, message):
        request = requests.post(
            f"{self.api_base}/email", headers=self.headers_default, json=message
        )
        return f"{request.status_code}\n{request.text}"
